@@ -29,16 +29,21 @@
 
 /* module global variables */
 
-static int sock;
+static int sock = -1;
 
 /* local rule repository */
 static rule_t *rule_info = NULL;
 static int rule_count = 0;
 
-#define IPTABLES_CMD "/sbin/iptables"
-#define CONFIGFILE	"/tmp/access.conf"
+#define CONFIGFILE	"/etc/access.conf"
 #define DEFAULT_INTERFACE "! lo"
 
+#ifdef MACH_IPAQ
+#define IPTABLES_CMD "/usr/sbin/iptables"
+#else
+#define IPTABLES_CMD "/sbin/iptables"
+#endif
+
 /* forwared definitions */
 
 static void do_command (pkcommand_t command, rule_t rule);
@@ -258,8 +263,10 @@ do_rules_apply()
 								  prot,
 								  portspec,
 								  target);
+#ifdef DEBUG			
+			printf("exec: %s\n",cmd);
+#endif
 			/* call iptables to add rule */
-printf("exec: %s\n",cmd);
 			system(cmd);
 			
 			g_free(cmd);
@@ -322,6 +329,8 @@ static void
 send_message (pkcontent_t ctype, rule_t *rule)
 {
 	pkmessage_t msg;
+	
+	if (sock < 0) return; /* no connection active */
 	msg.type = PK_FRONT;
 	msg.ctype = ctype;
 	if (rule) 
